pub struct Agent { /* private fields */ }Expand description
A running agent instance.
Create with Agent::new and the builder pattern,
then call start to run the background loop.
Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn new(config: NanoConfig) -> AgentBuilder
pub fn new(config: NanoConfig) -> AgentBuilder
Start configuring a new agent with default settings.
Sourcepub async fn send(
&self,
message: impl Into<String>,
) -> Result<String, NanoError>
pub async fn send( &self, message: impl Into<String>, ) -> Result<String, NanoError>
Send a message and wait for the complete text response.
Sourcepub async fn send_stream(
&self,
message: impl Into<String>,
) -> Result<UnboundedReceiver<AgentEvent>, NanoError>
pub async fn send_stream( &self, message: impl Into<String>, ) -> Result<UnboundedReceiver<AgentEvent>, NanoError>
Send a message and return a channel that receives all agent events.
Sourcepub fn reload_tools(&self, registry: ToolRegistry) -> Result<(), NanoError>
pub fn reload_tools(&self, registry: ToolRegistry) -> Result<(), NanoError>
Dynamically reload tools (only works in Nano mode).